@@ -324,7 +324,7 @@ used as you type it.""",
             intro="""
 Next, we need a name that can serve as a machine-readable Python package name
 for your application. This name must be PEP508-compliant - that means the name
-may only contain letters, numbers, hypehns and underscores; it can't contain
+may only contain letters, numbers, hyphens and underscores; it can't contain
 spaces or punctuation, and it can't start with a hyphen or underscore.
 
 Based on your formal name, we suggest an app name of '{default_app_name}',
@@ -424,8 +424,8 @@ What GUI toolkit do you want to use for this project?""",
             variable="GUI framework",
             options=[
                 'Toga',
-                'PySide2',
-                'PursuedPyBear',
+                'PySide2 (does not support iOS/Android deployment)',
+                'PursuedPyBear (does not support iOS/Android deployment)',
                 'None',
             ],
         )
@@ -442,7 +442,7 @@ What GUI toolkit do you want to use for this project?""",
             "bundle": bundle,
             "url": url,
             "license": project_license,
-            "gui_framework": gui_framework,
+            "gui_framework": (gui_framework.split())[0],
         }
 
     def new_app(self, template: Optional[str] = None, **options):
